@@ -1,10 +1,10 @@
 package Whelk::Schema::Definition::_Scalar;
-$Whelk::Schema::Definition::_Scalar::VERSION = '0.05';
+$Whelk::Schema::Definition::_Scalar::VERSION = '0.06';
 use Whelk::StrictBase 'Whelk::Schema::Definition';
 
-attr required => sub { !defined $_[0]->default };
-attr default => undef;
-attr example => undef;
+attr '?required' => sub { !defined $_[0]->default };
+attr '?default' => undef;
+attr '?example' => undef;
 
 sub has_default
 {
